# Changelog

## 0.1.0 (2025-07-28)


### Bug Fixes

* Reorganise repo ([#13](https://github.com/ecmwf/anemoi-plugins-ecmwf/issues/13)) ([8b47509](https://github.com/ecmwf/anemoi-plugins-ecmwf/commit/8b47509110db13f106f11397cbb2f89d80e82952))
